@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -33,6 +33,7 @@ from typing import Any, Callable, Dict, Hashable, List, Optional
 # Dictionaries
 # =============================================================================
 
+
 def get_case_insensitive_dict_key(d: Dict, k: str) -> Optional[str]:
     """
     Within the dictionary ``d``, find a key that matches (in case-insensitive
@@ -127,7 +128,8 @@ def rename_keys_in_dict(d: Dict[str, Any], renames: Dict[str, str]) -> None:
             if new_key in d:
                 raise ValueError(
                     f"rename_keys_in_dict: renaming {old_key!r} -> "
-                    f"{new_key!r} but new key already exists")
+                    f"{new_key!r} but new key already exists"
+                )
             d[new_key] = d.pop(old_key)
 
 
@@ -149,8 +151,9 @@ def reversedict(d: Dict[Any, Any]) -> Dict[Any, Any]:
     return {v: k for k, v in d.items()}
 
 
-def set_null_values_in_dict(d: Dict[str, Any],
-                            null_literals: List[Any]) -> None:
+def set_null_values_in_dict(
+    d: Dict[str, Any], null_literals: List[Any]
+) -> None:
     """
     Within ``d`` (in place), replace any values found in ``null_literals`` with
     ``None``.
@@ -168,9 +171,13 @@ def set_null_values_in_dict(d: Dict[str, Any],
 
 
 # noinspection PyPep8
-def map_keys_to_values(keys: List[Any], d: Dict[Any, Any], default: Any = None,
-                       raise_if_missing: bool = False,
-                       omit_if_missing: bool = False) -> List[Any]:
+def map_keys_to_values(
+    keys: List[Any],
+    d: Dict[Any, Any],
+    default: Any = None,
+    raise_if_missing: bool = False,
+    omit_if_missing: bool = False,
+) -> List[Any]:
     """
     The ``d`` dictionary contains a ``key -> value`` mapping.
 
@@ -189,8 +196,9 @@ def map_keys_to_values(keys: List[Any], d: Dict[Any, Any], default: Any = None,
     return result
 
 
-def dict_diff(d1: Dict[Any, Any], d2: Dict[Any, Any],
-              deleted_value: Any = None) -> Dict[Any, Any]:
+def dict_diff(
+    d1: Dict[Any, Any], d2: Dict[Any, Any], deleted_value: Any = None
+) -> Dict[Any, Any]:
     """
     Returns a representation of the changes that need to be made to ``d1`` to
     create ``d2``.
@@ -208,17 +216,16 @@ def dict_diff(d1: Dict[Any, Any], d2: Dict[Any, Any],
         ``d2``, the result dictionary has the entry ``{k: deleted_value}``.
 
     """
-    changes = {k: v for k, v in d2.items()
-               if k not in d1 or d2[k] != d1[k]}
+    changes = {k: v for k, v in d2.items() if k not in d1 or d2[k] != d1[k]}
     for k in d1.keys():
         if k not in d2:
             changes[k] = deleted_value
     return changes
 
 
-def delete_keys(d: Dict[Any, Any],
-                keys_to_delete: List[Any],
-                keys_to_keep: List[Any]) -> None:
+def delete_keys(
+    d: Dict[Any, Any], keys_to_delete: List[Any], keys_to_keep: List[Any]
+) -> None:
     """
     Deletes keys from a dictionary, in place.
 
@@ -239,6 +246,7 @@ def delete_keys(d: Dict[Any, Any],
 # Lazy dictionaries
 # =============================================================================
 
+
 class LazyDict(dict):
     """
     A dictionary that only evaluates the argument to :func:`setdefault` or
@@ -250,8 +258,10 @@ class LazyDict(dict):
     The ``*args``/``**kwargs`` parts are useful, but we don't want to have to
     name 'thunk' explicitly.
     """  # noqa
-    def get(self, key: Hashable, thunk: Any = None,
-            *args: Any, **kwargs: Any) -> Any:
+
+    def get(
+        self, key: Hashable, thunk: Any = None, *args: Any, **kwargs: Any
+    ) -> Any:
         if key in self:
             return self[key]
         elif callable(thunk):
@@ -259,8 +269,9 @@ class LazyDict(dict):
         else:
             return thunk
 
-    def setdefault(self, key: Hashable, thunk: Any = None,
-                   *args: Any, **kwargs: Any) -> Any:
+    def setdefault(
+        self, key: Hashable, thunk: Any = None, *args: Any, **kwargs: Any
+    ) -> Any:
         if key in self:
             return self[key]
         elif callable(thunk):
@@ -282,15 +293,18 @@ class LazyButHonestDict(dict):
     returning ``None``, when we're implementing this as a special function.
     In contrast, helpful to have ``*args``/``**kwargs`` options.
     """  # noqa
-    def lazyget(self, key: Hashable, thunk: Callable,
-                *args: Any, **kwargs: Any) -> Any:
+
+    def lazyget(
+        self, key: Hashable, thunk: Callable, *args: Any, **kwargs: Any
+    ) -> Any:
         if key in self:
             return self[key]
         else:
             return thunk(*args, **kwargs)
 
-    def lazysetdefault(self, key: Hashable, thunk: Callable,
-                       *args: Any, **kwargs: Any) -> Any:
+    def lazysetdefault(
+        self, key: Hashable, thunk: Callable, *args: Any, **kwargs: Any
+    ) -> Any:
         if key in self:
             return self[key]
         else:
@@ -301,12 +315,14 @@ class LazyButHonestDict(dict):
 # HashableDict
 # =============================================================================
 
+
 class HashableDict(dict):
     """
     A dictionary that can be hashed.
 
     See https://stackoverflow.com/questions/1151658/python-hashable-dicts.
     """
+
     def __hash__(self) -> int:
         return hash(tuple(sorted(self.items())))
 
@@ -315,6 +331,7 @@ class HashableDict(dict):
 # CaseInsensitiveDict
 # =============================================================================
 
+
 class CaseInsensitiveDict(dict):
     """
     A case-insensitive dictionary, as per
