@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -27,11 +27,7 @@
 """
 
 import math
-from math import (
-    exp as math_exp,
-    log as math_ln,
-    log10 as math_log10,
-)
+from math import exp as math_exp, log as math_ln, log10 as math_log10
 
 # For speed:
 INFINITY = math.inf
@@ -42,6 +38,7 @@ MINUS_INFINITY = -math.inf
 # Basic maths
 # =============================================================================
 
+
 def ln(x: float) -> float:
     """
     Version of :func:`math.log` that treats log(0) as ``-inf``, rather than
@@ -76,8 +73,34 @@ def ln(x: float) -> float:
         timeit.timeit('(MINUS_INFINITY for _ in range(1, 100))', number=10000)
         # 0.004293474368751049
 
-    """
-    return math_ln(x) if x != 0 else MINUS_INFINITY
+    Note also that although floats can't be "too close to zero" to cause an
+    error, other things (like Decimal objects) can. See
+    https://stackoverflow.com/questions/19095774/python-math-domain-errors-in-math-log-function
+
+    Exception catching is likely faster:
+
+    .. code-block: python
+
+        from cardinal_pythonlib.probability import ln
+        import timeit
+
+        # return math_ln(x) if x != 0 else MINUS_INFINITY
+        timeit.timeit('(ln(x) for x in range(1, 100))', number=10000)
+        # 0.012411762960255146
+        
+        # try... except ValueError...
+        timeit.timeit('(ln(x) for x in range(1, 100))', number=10000)
+        # 0.007783170789480209
+
+    """  # noqa
+    # return math_ln(x) if x != 0 else MINUS_INFINITY  # slower, less helpful
+    try:
+        return math_ln(x)
+    except ValueError:
+        if x < 0:
+            raise ValueError(f"Can't take log of a negative number: {x}")
+        # Either x > 0 but causing problems anyway, or x == 0.
+        return MINUS_INFINITY
 
 
 def log10(x: float) -> float:
@@ -94,13 +117,21 @@ def log10(x: float) -> float:
     See
     https://stackoverflow.com/questions/42980201/logarithm-of-zero-in-python.
     """
-    return math_log10(x) if x != 0 else MINUS_INFINITY
+    # return math_log10(x) if x != 0 else MINUS_INFINITY
+    try:
+        return math_log10(x)
+    except ValueError:
+        if x < 0:
+            raise ValueError(f"Can't take log of a negative number: {x}")
+        # Either x > 0 but causing problems anyway, or x == 0.
+        return MINUS_INFINITY
 
 
 # =============================================================================
 # Basic probability
 # =============================================================================
 
+
 def odds_from_probability(p: float) -> float:
     r"""
     Returns odds, given a probability.
@@ -223,8 +254,10 @@ def log_odds_from_1_in_n(n: float) -> float:
 # Bayesian update rules
 # =============================================================================
 
-def bayes_posterior(prior: float, likelihood: float,
-                    marginal_likelihood: float) -> float:
+
+def bayes_posterior(
+    prior: float, likelihood: float, marginal_likelihood: float
+) -> float:
     r"""
     Returns P(H | D), the posterior probability of hypothesis H, given data D.
 
@@ -257,8 +290,9 @@ def bayes_posterior(prior: float, likelihood: float,
     return likelihood * prior / marginal_likelihood
 
 
-def log_bayes_posterior(log_prior: float, log_likelihood: float,
-                        log_marginal_likelihood: float) -> float:
+def log_bayes_posterior(
+    log_prior: float, log_likelihood: float, log_marginal_likelihood: float
+) -> float:
     r"""
     Exactly equivalent to :func:`bayes_posterior`, but using log probability.
 
@@ -273,8 +307,7 @@ def log_bayes_posterior(log_prior: float, log_likelihood: float,
     return log_likelihood + log_prior - log_marginal_likelihood
 
 
-def posterior_odds(prior_odds: float,
-                   likelihood_ratio: float) -> float:
+def posterior_odds(prior_odds: float, likelihood_ratio: float) -> float:
     r"""
     Returns the posterior odds for a hypothesis, given the prior odds and the
     likelihood ratio.
@@ -307,16 +340,18 @@ def posterior_odds(prior_odds: float,
     return likelihood_ratio * prior_odds
 
 
-def log_posterior_odds(log_prior_odds: float,
-                       log_likelihood_ratio: float) -> float:
+def log_posterior_odds(
+    log_prior_odds: float, log_likelihood_ratio: float
+) -> float:
     r"""
     Exactly as for :func:`posterior_odds`, but with log odds.
     """
     return log_likelihood_ratio + log_prior_odds
 
 
-def log_likelihood_ratio_from_p(p_d_given_h: float,
-                                p_d_given_not_h: float) -> float:
+def log_likelihood_ratio_from_p(
+    p_d_given_h: float, p_d_given_not_h: float
+) -> float:
     r"""
     Returns
 
@@ -336,9 +371,9 @@ def log_likelihood_ratio_from_p(p_d_given_h: float,
     return ln(p_d_given_h) - ln(p_d_given_not_h)
 
 
-def log_posterior_odds_from_pdh_pdnh(log_prior_odds: float,
-                                     p_d_given_h: float,
-                                     p_d_given_not_h: float) -> float:
+def log_posterior_odds_from_pdh_pdnh(
+    log_prior_odds: float, p_d_given_h: float, p_d_given_not_h: float
+) -> float:
     r"""
     Calculates posterior odds.
 
@@ -358,16 +393,14 @@ def log_posterior_odds_from_pdh_pdnh(log_prior_odds: float,
     return log_posterior_odds(
         log_prior_odds=log_prior_odds,
         log_likelihood_ratio=log_likelihood_ratio_from_p(
-            p_d_given_h=p_d_given_h,
-            p_d_given_not_h=p_d_given_not_h
-        )
+            p_d_given_h=p_d_given_h, p_d_given_not_h=p_d_given_not_h
+        ),
     )
 
 
-def log_posterior_odds_from_bool_d_pdh_pdnh(log_prior_odds: float,
-                                            d: bool,
-                                            p_d_given_h: float,
-                                            p_d_given_not_h: float) -> float:
+def log_posterior_odds_from_bool_d_pdh_pdnh(
+    log_prior_odds: float, d: bool, p_d_given_h: float, p_d_given_not_h: float
+) -> float:
     r"""
     Calculates posterior odds.
 
@@ -389,18 +422,15 @@ def log_posterior_odds_from_bool_d_pdh_pdnh(log_prior_odds: float,
     if d:
         # D is true
         log_lr = log_likelihood_ratio_from_p(
-            p_d_given_h=p_d_given_h,
-            p_d_given_not_h=p_d_given_not_h
+            p_d_given_h=p_d_given_h, p_d_given_not_h=p_d_given_not_h
         )
     else:
         # not-D is true
         p_not_d_given_h = 1 - p_d_given_h
         p_not_d_given_not_h = 1 - p_d_given_not_h
         log_lr = log_likelihood_ratio_from_p(
-            p_d_given_h=p_not_d_given_h,
-            p_d_given_not_h=p_not_d_given_not_h
+            p_d_given_h=p_not_d_given_h, p_d_given_not_h=p_not_d_given_not_h
         )
     return log_posterior_odds(
-        log_prior_odds=log_prior_odds,
-        log_likelihood_ratio=log_lr
+        log_prior_odds=log_prior_odds, log_likelihood_ratio=log_lr
     )
