@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -37,8 +37,9 @@ log = logging.getLogger(__name__)
 FuncType = Callable[..., Any]
 
 
-def rate_limited(max_per_second: Optional[Union[int, float]]) \
-        -> Callable[[FuncType], FuncType]:
+def rate_limited(
+    max_per_second: Optional[Union[int, float]]
+) -> Callable[[FuncType], FuncType]:
     """
     Returns a function that rate-limits another function to the specified
     frequency. Can be used as a decorator, e.g.
