@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -51,13 +51,13 @@ log = get_brace_style_log_with_null_handler(__name__)
 # http://docs.sqlalchemy.org/en/latest/core/constraints.html#configuring-constraint-naming-conventions  # noqa
 
 ALEMBIC_NAMING_CONVENTION = {
-    "ix": 'ix_%(column_0_label)s',
+    "ix": "ix_%(column_0_label)s",
     "uq": "uq_%(table_name)s_%(column_0_name)s",
     # "ck": "ck_%(table_name)s_%(constraint_name)s",  # too long?
     # ... https://groups.google.com/forum/#!topic/sqlalchemy/SIT4D8S9dUg
     "ck": "ck_%(table_name)s_%(column_0_name)s",
     "fk": "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
-    "pk": "pk_%(table_name)s"
+    "pk": "pk_%(table_name)s",
 }
 
 DEFAULT_ALEMBIC_VERSION_TABLE = "alembic_version"
@@ -68,10 +68,12 @@ DEFAULT_ALEMBIC_VERSION_TABLE = "alembic_version"
 # =============================================================================
 # https://stackoverflow.com/questions/24622170/using-alembic-api-from-inside-application-code  # noqa
 
+
 def get_head_revision_from_alembic(
-        alembic_config_filename: str,
-        alembic_base_dir: str = None,
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE) -> str:
+    alembic_config_filename: str,
+    alembic_base_dir: str = None,
+    version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
+) -> str:
     """
     Ask Alembic what its head revision is (i.e. where the Python code would
     like the database to be at).
@@ -87,15 +89,13 @@ def get_head_revision_from_alembic(
     os.chdir(alembic_base_dir)  # so the directory in the config file works
     config = Config(alembic_config_filename)
     script = ScriptDirectory.from_config(config)
-    with EnvironmentContext(config,
-                            script,
-                            version_table=version_table):
+    with EnvironmentContext(config, script, version_table=version_table):
         return script.get_current_head()
 
 
 def get_current_revision(
-        database_url: str,
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE) -> str:
+    database_url: str, version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE
+) -> str:
     """
     Ask the database what its current revision is.
 
@@ -105,16 +105,17 @@ def get_current_revision(
     """
     engine = create_engine(database_url)
     conn = engine.connect()
-    opts = {'version_table': version_table}
+    opts = {"version_table": version_table}
     mig_context = MigrationContext.configure(conn, opts=opts)
     return mig_context.get_current_revision()
 
 
 def get_current_and_head_revision(
-        database_url: str,
-        alembic_config_filename: str,
-        alembic_base_dir: str = None,
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE) -> Tuple[str, str]:
+    database_url: str,
+    alembic_config_filename: str,
+    alembic_base_dir: str = None,
+    version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
+) -> Tuple[str, str]:
     """
     Returns a tuple of ``(current_revision, head_revision)``; see
     :func:`get_current_revision` and :func:`get_head_revision_from_alembic`.
@@ -130,14 +131,13 @@ def get_current_and_head_revision(
     head_revision = get_head_revision_from_alembic(
         alembic_config_filename=alembic_config_filename,
         alembic_base_dir=alembic_base_dir,
-        version_table=version_table
+        version_table=version_table,
     )
     log.debug("Intended database version: {}", head_revision)
 
     # Where we want to be
     current_revision = get_current_revision(
-        database_url=database_url,
-        version_table=version_table
+        database_url=database_url, version_table=version_table
     )
     log.debug("Current database version: {}", current_revision)
 
@@ -147,12 +147,13 @@ def get_current_and_head_revision(
 
 @preserve_cwd
 def upgrade_database(
-        alembic_config_filename: str,
-        alembic_base_dir: str = None,
-        starting_revision: str = None,
-        destination_revision: str = "head",
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
-        as_sql: bool = False) -> None:
+    alembic_config_filename: str,
+    alembic_base_dir: str = None,
+    starting_revision: str = None,
+    destination_revision: str = "head",
+    version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
+    as_sql: bool = False,
+) -> None:
     """
     Use Alembic to upgrade our database.
 
@@ -192,17 +193,21 @@ def upgrade_database(
     def upgrade(rev, context):
         return script._upgrade_revs(destination_revision, rev)
 
-    log.info("Upgrading database to revision {!r} using Alembic",
-             destination_revision)
+    log.info(
+        "Upgrading database to revision {!r} using Alembic",
+        destination_revision,
+    )
 
-    with EnvironmentContext(config,
-                            script,
-                            fn=upgrade,
-                            as_sql=as_sql,
-                            starting_rev=starting_revision,
-                            destination_rev=destination_revision,
-                            tag=None,
-                            version_table=version_table):
+    with EnvironmentContext(
+        config,
+        script,
+        fn=upgrade,
+        as_sql=as_sql,
+        starting_rev=starting_revision,
+        destination_rev=destination_revision,
+        tag=None,
+        version_table=version_table,
+    ):
         script.run_env()
 
     log.info("Database upgrade completed")
@@ -210,12 +215,13 @@ def upgrade_database(
 
 @preserve_cwd
 def downgrade_database(
-        alembic_config_filename: str,
-        destination_revision: str,
-        alembic_base_dir: str = None,
-        starting_revision: str = None,
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
-        as_sql: bool = False) -> None:
+    alembic_config_filename: str,
+    destination_revision: str,
+    alembic_base_dir: str = None,
+    starting_revision: str = None,
+    version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
+    as_sql: bool = False,
+) -> None:
     """
     Use Alembic to downgrade our database. USE WITH EXTREME CAUTION.
     "revision" is the destination revision.
@@ -255,17 +261,21 @@ def downgrade_database(
     def downgrade(rev, context):
         return script._downgrade_revs(destination_revision, rev)
 
-    log.info("Downgrading database to revision {!r} using Alembic",
-             destination_revision)
+    log.info(
+        "Downgrading database to revision {!r} using Alembic",
+        destination_revision,
+    )
 
-    with EnvironmentContext(config,
-                            script,
-                            fn=downgrade,
-                            as_sql=as_sql,
-                            starting_rev=starting_revision,
-                            destination_rev=destination_revision,
-                            tag=None,
-                            version_table=version_table):
+    with EnvironmentContext(
+        config,
+        script,
+        fn=downgrade,
+        as_sql=as_sql,
+        starting_rev=starting_revision,
+        destination_rev=destination_revision,
+        tag=None,
+        version_table=version_table,
+    ):
         script.run_env()
 
     log.info("Database downgrade completed")
@@ -273,10 +283,11 @@ def downgrade_database(
 
 @preserve_cwd
 def create_database_migration_numbered_style(
-        alembic_ini_file: str,
-        alembic_versions_dir: str,
-        message: str,
-        n_sequence_chars: int = 4) -> None:
+    alembic_ini_file: str,
+    alembic_versions_dir: str,
+    message: str,
+    n_sequence_chars: int = 4,
+) -> None:
     """
     Create a new Alembic migration script.
 
@@ -326,14 +337,19 @@ def create_database_migration_numbered_style(
     """  # noqa
     file_regex = r"\d{" + str(n_sequence_chars) + r"}_\S*\.py$"
 
-    _, _, existing_version_filenames = next(os.walk(alembic_versions_dir),
-                                            (None, None, []))
+    _, _, existing_version_filenames = next(
+        os.walk(alembic_versions_dir), (None, None, [])
+    )
     existing_version_filenames = [
-        x for x in existing_version_filenames if re.match(file_regex, x)]
-    log.debug("Existing Alembic version script filenames: {!r}",
-              existing_version_filenames)
-    current_seq_strs = [x[:n_sequence_chars]
-                        for x in existing_version_filenames]
+        x for x in existing_version_filenames if re.match(file_regex, x)
+    ]
+    log.debug(
+        "Existing Alembic version script filenames: {!r}",
+        existing_version_filenames,
+    )
+    current_seq_strs = [
+        x[:n_sequence_chars] for x in existing_version_filenames
+    ]
     current_seq_strs.sort()
     if not current_seq_strs:
         current_seq_str = None
@@ -353,27 +369,33 @@ Generating new revision with Alembic...
     you may have elected to change that in your env.py.]
         """,
         current_seq_str,
-        new_seq_str
+        new_seq_str,
     )
 
     alembic_ini_dir = os.path.dirname(alembic_ini_file)
     os.chdir(alembic_ini_dir)
-    cmdargs = ['alembic',
-               '-c', alembic_ini_file,
-               'revision',
-               '--autogenerate',
-               '-m', message,
-               '--rev-id', new_seq_str]
+    cmdargs = [
+        "alembic",
+        "-c",
+        alembic_ini_file,
+        "revision",
+        "--autogenerate",
+        "-m",
+        message,
+        "--rev-id",
+        new_seq_str,
+    ]
     log.info("From directory {!r}, calling: {!r}", alembic_ini_dir, cmdargs)
     subprocess.call(cmdargs)
 
 
 def stamp_allowing_unusual_version_table(
-        config: Config,
-        revision: str,
-        sql: bool = False,
-        tag: str = None,
-        version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE) -> None:
+    config: Config,
+    revision: str,
+    sql: bool = False,
+    tag: str = None,
+    version_table: str = DEFAULT_ALEMBIC_VERSION_TABLE,
+) -> None:
     """
     Stamps the Alembic version table with the given revision; don't run any
     migrations.
@@ -389,19 +411,21 @@ def stamp_allowing_unusual_version_table(
     if ":" in revision:
         if not sql:
             raise CommandError("Range revision not allowed")
-        starting_rev, revision = revision.split(':', 2)
+        starting_rev, revision = revision.split(":", 2)
 
     # noinspection PyUnusedLocal
     def do_stamp(rev: str, context):
         # noinspection PyProtectedMember
         return script._stamp_revs(revision, rev)
 
-    with EnvironmentContext(config,
-                            script,
-                            fn=do_stamp,
-                            as_sql=sql,
-                            destination_rev=revision,
-                            starting_rev=starting_rev,
-                            tag=tag,
-                            version_table=version_table):
+    with EnvironmentContext(
+        config,
+        script,
+        fn=do_stamp,
+        as_sql=sql,
+        destination_rev=revision,
+        starting_rev=starting_rev,
+        tag=tag,
+        version_table=version_table,
+    ):
         script.run_env()
