@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -32,6 +32,7 @@ import unicodedata
 # Finding
 # =============================================================================
 
+
 def find_nth(s: str, x: str, n: int = 0, overlap: bool = False) -> int:
     """
     Finds the position of *n*\ th occurrence of ``x`` in ``s``, or ``-1`` if
@@ -58,18 +59,20 @@ def find_nth(s: str, x: str, n: int = 0, overlap: bool = False) -> int:
 # Splitting
 # =============================================================================
 
+
 def split_string(x: str, n: int) -> List[str]:
     """
     Split string into chunks of length n
     """
     # https://stackoverflow.com/questions/9475241/split-string-every-nth-character  # noqa
-    return [x[i:i+n] for i in range(0, len(x), n)]
+    return [x[i : i + n] for i in range(0, len(x), n)]
 
 
 # =============================================================================
 # Replacement
 # =============================================================================
 
+
 def multiple_replace(text: str, rep: Dict[str, str]) -> str:
     """
     Returns a version of ``text`` in which the keys of ``rep`` (a dict) have
@@ -83,8 +86,9 @@ def multiple_replace(text: str, rep: Dict[str, str]) -> str:
     return pattern.sub(lambda m: rep[re.escape(m.group(0))], text)
 
 
-def replace_in_list(stringlist: Iterable[str],
-                    replacedict: Dict[str, str]) -> List[str]:
+def replace_in_list(
+    stringlist: Iterable[str], replacedict: Dict[str, str]
+) -> List[str]:
     """
     Returns a list produced by applying :func:`multiple_replace` to every
     string in ``stringlist``.
@@ -107,6 +111,7 @@ def replace_in_list(stringlist: Iterable[str],
 # Mangling to ASCII
 # =============================================================================
 
+
 def mangle_unicode_to_ascii(s: Any) -> str:
     """
     Mangle unicode to ASCII, losing accents etc. in the process.
@@ -117,9 +122,9 @@ def mangle_unicode_to_ascii(s: Any) -> str:
     if not isinstance(s, str):
         s = str(s)
     return (
-        unicodedata.normalize('NFKD', s)
-                   .encode('ascii', 'ignore')  # gets rid of accents
-                   .decode('ascii')  # back to a string
+        unicodedata.normalize("NFKD", s)
+        .encode("ascii", "ignore")  # gets rid of accents
+        .decode("ascii")  # back to a string
     )
 
 
@@ -127,6 +132,7 @@ def mangle_unicode_to_ascii(s: Any) -> str:
 # Making strings and string lists
 # =============================================================================
 
+
 def strnum(prefix: str, num: int, suffix: str = "") -> str:
     """
     Makes a string of the format ``<prefix><number><suffix>``.
